@@ -1,36 +1,10 @@
-import subprocess
 from typing import List, Dict
-
-class Commands():
-    """ Class that specifies all PIP commands that are implemented
-        For referece, please use pip --help """
-
-    @staticmethod
-    def _create_cmd(*args):
-        exec_cmd = subprocess.run(
-            list(args),
-            check=True,
-            capture_output=True,
-            text=True)
-        return exec_cmd
-
-    @classmethod
-    def _list_packages(cls):
-        return cls._create_cmd('pip', 'freeze')
-    
-    @classmethod
-    def _install(cls, name:str):
-        return cls._create_cmd('pip', 'install', name)
-
-    @classmethod
-    def _uninstall(cls, name:str):
-        return cls._create_cmd('pip', 'uninstall', name, '-y')
-
+from .commands import Commands
 
 class PIP():
     """ Python wrapper for PIP installer """
 
-    __version__ = '0.30'
+    __version__ = '0.33'
     __author__ = 'Jordan Raychev'
     __email__ = 'jpraychev at gmail dot com'
     __license__ = 'MIT. Please refer to LICENSE file'
@@ -72,7 +46,7 @@ class PIP():
             raise TypeError(f'Expected {package_name} to be a string')
         try:
             package = Commands._install(name=package_name)
-        except subprocess.CalledProcessError:
+        except Exception:
             return f'{package_name} could not be installed\n'
         return package.stdout
 
@@ -100,7 +74,7 @@ class PIP():
         for package_name in package_names:
             try:
                 package = Commands._install(name=package_name)
-            except subprocess.CalledProcessError as e:
+            except Exception:
                 failure.append(package_name)
                 break
             success.append(package_name)
@@ -110,6 +84,7 @@ class PIP():
     @staticmethod
     def bulk_uninstall(package_names:List[str]) -> str:
         """ Bulk uninstall of packages from a list """
+
         success = []
         failure = []
         if not isinstance(package_names, list):
@@ -130,6 +105,30 @@ class PIP():
         lp = Commands._list_packages()
         installed_packages = lp.stdout.split('\n')[:-1]
 
-        with open(file='requirements.txt', mode='w') as file:
-            for package in installed_packages:
-                file.write(package + '\n')
\ No newline at end of file
+        try:
+            with open(file='requirements.txt', mode='w') as file:
+                for package in installed_packages:
+                    file.write(package + '\n')
+        except Exception:
+            return 'Could not export python packages'
+        return 'Python packages exported to requirements.txt'
+
+    @staticmethod
+    def clear_cache():
+        """ Clears pip cache current environment """
+
+        try:
+            cache = Commands._clear_cache()
+        except Exception:
+            return 'Cache is probably empty. Please run show_cache to verify first.'
+        return cache.stdout
+    
+    @staticmethod
+    def show_cache():
+        """ Shows pip cache for current environment """
+
+        try:
+            cache = Commands._show_cache()
+        except Exception:
+            return 'Something went wrong'
+        return cache.stdout
\ No newline at end of file
